@@ -1,16 +1,16 @@
 import sys
 
 sys.path += ["../../"]
-import rpyc
 import atexit
 import threading
-
 from enum import Enum
+from multiprocessing import Pipe, Process
 from time import sleep
-from multiprocessing import Process, Pipe
+
+import rpyc
 
 from linien.config import ACQUISITION_PORT
-from linien.server.utils import stop_nginx, start_nginx, flash_fpga
+from linien.server.utils import flash_fpga, start_nginx, stop_nginx
 
 
 class AcquisitionConnectionError(Exception):
@@ -19,7 +19,7 @@ class AcquisitionConnectionError(Exception):
 
 class AcquisitionProcessSignals(Enum):
     SHUTDOWN = 0
-    SET_RAMP_SPEED = 2
+    SET_SWEEP_SPEED = 2
     SET_LOCK_STATUS = 3
     SET_CSR = 4
     SET_IIR_CSR = 5
@@ -27,6 +27,7 @@ class AcquisitionProcessSignals(Enum):
     CONTINUE_ACQUISITION = 6
     FETCH_QUADRATURES = 7
     SET_RAW_ACQUISITION = 8
+    SET_DUAL_CHANNEL = 9
 
 
 class AcquisitionMaster:
@@ -85,15 +86,17 @@ class AcquisitionMaster:
                 data = pipe.recv()
                 if data[0] == AcquisitionProcessSignals.SHUTDOWN:
                     raise SystemExit()
-                elif data[0] == AcquisitionProcessSignals.SET_RAMP_SPEED:
+                elif data[0] == AcquisitionProcessSignals.SET_SWEEP_SPEED:
                     speed = data[1]
-                    acquisition.exposed_set_ramp_speed(speed)
+                    acquisition.exposed_set_sweep_speed(speed)
                 elif data[0] == AcquisitionProcessSignals.SET_LOCK_STATUS:
                     acquisition.exposed_set_lock_status(data[1])
                 elif data[0] == AcquisitionProcessSignals.FETCH_QUADRATURES:
-                    acquisition.exposed_set_fetch_quadratures(data[1])
+                    acquisition.exposed_set_fetch_additional_signals(data[1])
                 elif data[0] == AcquisitionProcessSignals.SET_RAW_ACQUISITION:
                     acquisition.exposed_set_raw_acquisition(data[1])
+                elif data[0] == AcquisitionProcessSignals.SET_DUAL_CHANNEL:
+                    acquisition.exposed_set_dual_channel(data[1])
                 elif data[0] == AcquisitionProcessSignals.SET_CSR:
                     acquisition.exposed_set_csr(*data[1])
                 elif data[0] == AcquisitionProcessSignals.SET_IIR_CSR:
@@ -123,14 +126,14 @@ class AcquisitionMaster:
 
         start_nginx()
 
-    def set_ramp_speed(self, speed):
-        self.acq_process.send((AcquisitionProcessSignals.SET_RAMP_SPEED, speed))
+    def set_sweep_speed(self, speed):
+        self.acq_process.send((AcquisitionProcessSignals.SET_SWEEP_SPEED, speed))
 
     def lock_status_changed(self, status):
         if self.acq_process:
             self.acq_process.send((AcquisitionProcessSignals.SET_LOCK_STATUS, status))
 
-    def fetch_quadratures_changed(self, status):
+    def fetch_additional_signals_changed(self, status):
         if self.acq_process:
             self.acq_process.send((AcquisitionProcessSignals.FETCH_QUADRATURES, status))
 
@@ -152,3 +155,6 @@ class AcquisitionMaster:
         self.acq_process.send(
             (AcquisitionProcessSignals.SET_RAW_ACQUISITION, (enabled, decimation))
         )
+
+    def set_dual_channel(self, enabled):
+        self.acq_process.send((AcquisitionProcessSignals.SET_DUAL_CHANNEL, enabled))
