@@ -1,12 +1,12 @@
-from linien.server.optimization.utils import FINAL_ZOOM_FACTOR
-from linien.server.optimization.engine import OptimizerEngine
 import pickle
-import numpy as np
 import traceback
 
-from linien.common import determine_shift_by_correlation, get_lock_point
-from linien.server.autolock import Approacher
+import numpy as np
 
+from linien.common import determine_shift_by_correlation, get_lock_point
+from linien.server.approach_line import Approacher
+from linien.server.optimization.engine import OptimizerEngine
+from linien.server.optimization.utils import FINAL_ZOOM_FACTOR
 
 
 class OptimizeSpectroscopy:
@@ -23,9 +23,9 @@ class OptimizeSpectroscopy:
         self.next_recentering_iteration = self.recenter_after
         self.allow_increase_of_recentering_interval = True
 
-        self.initial_ramp_speed = self.parameters.ramp_speed.value
-        self.initial_ramp_amplitude = self.parameters.ramp_amplitude.value
-        self.initial_ramp_center = self.parameters.center.value
+        self.initial_sweep_speed = self.parameters.sweep_speed.value
+        self.initial_sweep_amplitude = self.parameters.sweep_amplitude.value
+        self.initial_sweep_center = self.parameters.sweep_center.value
 
     def run(self, x0, x1, spectrum):
         self.parameters.optimization_failed.value = False
@@ -40,16 +40,22 @@ class OptimizeSpectroscopy:
         self.record_first_error_signal(spectrum)
 
         params = self.parameters
-        self.engine = OptimizerEngine(
-            self.control, params
-        )
+        self.engine = OptimizerEngine(self.control, params)
         params.to_plot.on_change(self.react_to_new_spectrum)
         params.optimization_running.value = True
         params.optimization_improvement.value = 0
 
     def record_first_error_signal(self, error_signal):
-        mean_signal, _2, target_zoom, rolled_error_signal = get_lock_point(
-            error_signal, *list(sorted([self.x0, self.x1])),
+        (
+            mean_signal,
+            _2,
+            target_zoom,
+            rolled_error_signal,
+            line_width,
+            peak_idxs,
+        ) = get_lock_point(
+            error_signal,
+            *list(sorted([self.x0, self.x1])),
             final_zoom_factor=FINAL_ZOOM_FACTOR
         )
 
@@ -57,12 +63,14 @@ class OptimizeSpectroscopy:
         self.first_error_signal = rolled_error_signal
 
         self.approacher = Approacher(
-            self.control, self.parameters, self.first_error_signal,
-            self.target_zoom, mean_signal,
-            allow_ramp_speed_change=False
+            self.control,
+            self.parameters,
+            self.first_error_signal,
+            self.target_zoom,
+            mean_signal,
+            allow_sweep_speed_change=False,
         )
 
-
     def react_to_new_spectrum(self, spectrum):
         if not self.parameters.optimization_running.value:
             return
@@ -74,8 +82,8 @@ class OptimizeSpectroscopy:
             channel = params.optimization_channel.value
             spectrum_idx = 1 if not dual_channel else (1, 2)[channel]
             unpickled = pickle.loads(spectrum)
-            spectrum = unpickled['error_signal_%d' % spectrum_idx]
-            quadrature = unpickled['error_signal_%d_quadrature' % spectrum_idx]
+            spectrum = unpickled["error_signal_%d" % spectrum_idx]
+            quadrature = unpickled["error_signal_%d_quadrature" % spectrum_idx]
 
             if self.parameters.optimization_approaching.value:
                 approaching_finished = self.approacher.approach_line(spectrum)
@@ -91,7 +99,9 @@ class OptimizeSpectroscopy:
                     self.engine.tell(spectrum, quadrature)
 
                 center_line = self.iteration == self.next_recentering_iteration
-                center_line_next_time = self.iteration + 1 == self.next_recentering_iteration
+                center_line_next_time = (
+                    self.iteration + 1 == self.next_recentering_iteration
+                )
 
                 if self.iteration > 1:
                     if center_line:
@@ -99,11 +109,15 @@ class OptimizeSpectroscopy:
                         shift, _, _2 = determine_shift_by_correlation(
                             1, self.initial_spectrum, spectrum
                         )
-                        params.center.value -= shift * params.ramp_amplitude.value
-                        self.control.exposed_write_data()
+                        params.sweep_center.value -= (
+                            shift * params.sweep_amplitude.value
+                        )
+                        self.control.exposed_write_registers()
 
-                        if self.allow_increase_of_recentering_interval and \
-                                abs(shift) < 2 / FINAL_ZOOM_FACTOR:
+                        if (
+                            self.allow_increase_of_recentering_interval
+                            and abs(shift) < 2 / FINAL_ZOOM_FACTOR
+                        ):
                             self.recenter_after *= 2
                         else:
                             self.allow_increase_of_recentering_interval = False
@@ -113,13 +127,15 @@ class OptimizeSpectroscopy:
                         self.engine.tell(spectrum, quadrature)
 
                 if not self.engine.finished():
-                    self.engine.request_and_set_new_parameters(use_initial_parameters=center_line_next_time)
+                    self.engine.request_and_set_new_parameters(
+                        use_initial_parameters=center_line_next_time
+                    )
                 else:
                     # we are done!
                     self.exposed_stop(True)
 
-        except:
-            print('exception at optimization task')
+        except Exception:
+            print("exception at optimization task")
             traceback.print_exc()
             self.parameters.optimization_failed.value = True
             self.exposed_stop(False)
@@ -139,9 +155,9 @@ class OptimizeSpectroscopy:
     def reset_scan(self):
         self.control.pause_acquisition()
 
-        self.parameters.ramp_speed.value = self.initial_ramp_speed
-        self.parameters.ramp_amplitude.value = self.initial_ramp_amplitude
-        self.parameters.center.value = self.initial_ramp_center
-        self.control.exposed_write_data()
+        self.parameters.sweep_speed.value = self.initial_sweep_speed
+        self.parameters.sweep_amplitude.value = self.initial_sweep_amplitude
+        self.parameters.sweep_center.value = self.initial_sweep_center
+        self.control.exposed_write_registers()
 
-        self.control.continue_acquisition()
\ No newline at end of file
+        self.control.continue_acquisition()
