@@ -1,6 +1,12 @@
-from linien.server.parameters_base import BaseParameters, Parameter
+from linien.common import (
+    AUTO_DETECT_AUTOLOCK_MODE,
+    FAST_AUTOLOCK,
+    PSD_ALGORITHM_LPSD,
+    MHz,
+    Vpp,
+)
 from linien.config import DEFAULT_COLORS, N_COLORS
-from linien.common import AUTO_DETECT_AUTOLOCK_MODE, FAST_AUTOLOCK, Vpp, MHz
+from linien.server.parameters_base import BaseParameters, Parameter
 
 
 class Parameters(BaseParameters):
@@ -18,7 +24,7 @@ class Parameters(BaseParameters):
         # if a parameter influences the behavior of the FPGA, it has to be
         # written to the FPGA as well (`control` is an instance of
         # `RedPitayaControlService`):
-        control.exposed_write_data()
+        control.exposed_write_registers()
 
     On the client side, access happens through `RemoteParameters` which
     transparently mimics the behavior of this class. Have a look at the comments
@@ -31,9 +37,10 @@ class Parameters(BaseParameters):
         # parameters whose values are saved by the client and restored if the
         # client connects to the RedPitaya with no server running.
         self._restorable_parameters = (
+            "fast_mode",
             "modulation_amplitude",
             "modulation_frequency",
-            "ramp_speed",
+            "sweep_speed",
             "demodulation_phase_a",
             "demodulation_multiplier_a",
             "demodulation_phase_b",
@@ -85,16 +92,44 @@ class Parameters(BaseParameters):
             "autolock_determine_offset",
             "autolock_mode_preference",
             "psd_acquisition_max_decimation",
-            "psd_acquisition_decimation_step",
         )
 
+        # the `to_plot` parameter is a pickled dictionary that contains signals
+        # that may be plotted. Depending on the locking state, it may contain these
+        # signals:
+        # Unlocked state:
+        #   - `error_signal_1` and `error_signal_1_quadrature`:
+        #       IQ-demodulated and low-pass-filtered error signals from
+        #       ANALOG IN 0
+        #   - `error_signal_2` and `error_signal_2_quadrature`:
+        #       IQ-demodulated and low-pass-filtered error signals from
+        #       ANALOG IN 1. These signals are only available if in dual-channel
+        #       spectroscopy mode is enabled. Otherwise the un-demodulated
+        #       monitor_signal` is shown.
+        #   - `monitor_signal`:
+        #       Signal recorded from ANALOG IN 1 without demodulation. Only
+        #       available if dual channel mode is not enabled.
+        #
+        # Locked state:
+        #   - `error_signal`:
+        #       Error signal that is fed into the PID controller.
+        #   - `control_signal`:
+        #       Output of the PID controller.
+        #   - `slow`:
+        #       Output of slow additional integrator on slow analog output.
+        #       Note that this value is not an array but a single point.
         self.to_plot = Parameter(sync=False)
+        # A dictionary that contains mean, standard deviation, minimum value and
+        # maximum value for all the signals contained in `to_plot`.
+        # Exemplary dictionary keys are `error_signal_mean`,
+        # `control_signal_std`, `monitor_signal_min` or `error_signal_2_max`.
+        self.signal_stats = Parameter(sync=False)
 
         #           --------- GENERAL PARAMETERS ---------
         # configures the output of the modulation frequency. A value of 0 means
         # FAST OUT 1 and a value of 1 corresponds to FAST OUT 2
         self.mod_channel = Parameter(start=0, min_=0, max_=1)
-        # configures the output of the scan ramp:
+        # configures the output of the scan sweep:
         #       0 --> FAST OUT 1
         #       1 --> FAST OUT 2
         #       2 --> ANALOG OUT 0 (slow channel)
@@ -126,7 +161,7 @@ class Parameters(BaseParameters):
                 Parameter(start=0, min_=0, max_=(2 ** 15) - 1),
             )
 
-        # If `True`, this parameter turns off the ramp and starts the PID
+        # If `True`, this parameter turns off the sweep and starts the PID
         self.lock = Parameter(start=False)
 
         # for both fast outputs and the analog out, define whether tuning the
@@ -142,6 +177,9 @@ class Parameters(BaseParameters):
         self.control_signal_history = Parameter(
             start={"times": [], "values": []}, sync=False
         )
+        self.monitor_signal_history = Parameter(
+            start={"times": [], "values": []}, sync=False
+        )
         # if this boolean is `True`, no new spectroscopy data is sent to the
         # clients. This parameter is used when writing data to FPGA that would
         # result in cropped / distorted signals being displayed.
@@ -149,22 +187,29 @@ class Parameters(BaseParameters):
 
         # this parameter is not exposed to GUI. It is used by the autolock or
         # normal lock to fetch less data if they are not needed.
-        self.fetch_quadratures = Parameter(start=True)
+        self.fetch_additional_signals = Parameter(start=True)
 
-        #           --------- RAMP PARAMETERS ---------
+        # this is just a counter that is automatically increased every second.
+        # Its purpose is to allow for periodic tasks on the server:
+        # just register an `on_change` listener for this parameter.
+        self.ping = Parameter(start=0)
 
-        # how big should the ramp amplitude be relative to the full output range
-        # of RedPitaya? An amplitude of 1 corresponds to a ramp from -1V to 1V,
-        # an amplitude 0f .1 to a ramp from -.1 to .1V (assuming that `center`
-        # is 0, see below)
-        self.ramp_amplitude = Parameter(min_=0.001, max_=1, start=1)
-        # The center position of the ramp in volts. As the output range of
-        # RedPitaya is [-1, 1], `center` has the same limits.
-        self.center = Parameter(min_=-1, max_=1, start=0)
-        # The ramp speed in internal units. The actual speed is given by
-        #       f_real = 3.8 kHz / (2 ** ramp_speed)
+        #           --------- SWEEP PARAMETERS ---------
+
+        # Amplitude of the sweep in units of 0.5 * Vpp of the output (2 V for fast
+        # outputs (range +/- 1 V) and 0.9 V for slow outputs (range 0 V to 1.8 V). That
+        # means an amplitude of 1.0 corresponds to the full sweep range in both cases.
+        self.sweep_amplitude = Parameter(min_=0.001, max_=1, start=1)
+        # The center position of the sweep. If a fast output is used for the sweep this
+        #  is the sweep center position in volts. If the slow output is used the
+        # interval [-1, +1] of this parameter is mapped to the interval [0V, +1.8V].
+        self.sweep_center = Parameter(min_=-1, max_=1, start=0)
+        # The sweep speed in internal units. The actual speed is given by
+        #       f_real = 3.8 kHz / (2 ** sweep_speed)
         # Allowed values are [0, ..., 16]
-        self.ramp_speed = Parameter(min_=0, max_=32, start=8)
+        self.sweep_speed = Parameter(min_=0, max_=32, start=8)
+        # If set to `True`, this parameter pauses the sweep at the `sweep_center`.
+        self.sweep_pause = Parameter(start=False)
 
         #           --------- MODULATION PARAMETERS ---------
 
@@ -183,6 +228,9 @@ class Parameters(BaseParameters):
         self.modulation_frequency = Parameter(min_=0, max_=0xFFFFFFFF, start=15 * MHz)
 
         #           --------- DEMODULATION AND FILTER PARAMETERS ---------
+        # fast mode allows to bypass demodulation and IIR filtering of the fast
+        # channels.
+        self.fast_mode = Parameter(start=False)
         # Linien allows for two simulataneous demodulation channels. By default,
         # only one is enabled. This is controlled by `dual_channel`.
         self.dual_channel = Parameter(start=False)
@@ -282,7 +330,7 @@ class Parameters(BaseParameters):
         self.autolock_mode_preference = Parameter(start=AUTO_DETECT_AUTOLOCK_MODE)
         self.autolock_mode = Parameter(start=FAST_AUTOLOCK)
         self.autolock_time_scale = Parameter(start=0)
-        self.autolock_instructions = Parameter(start=[])
+        self.autolock_instructions = Parameter(start=[], sync=False)
         self.autolock_final_wait_time = Parameter(start=0)
         self.autolock_selection = Parameter(start=False)
         self.autolock_running = Parameter(start=False)
@@ -293,7 +341,7 @@ class Parameters(BaseParameters):
         self.autolock_locked = Parameter(start=False)
         self.autolock_retrying = Parameter(start=False)
         self.autolock_determine_offset = Parameter(start=True)
-        self.autolock_initial_ramp_amplitude = Parameter(start=1)
+        self.autolock_initial_sweep_amplitude = Parameter(start=1)
 
         #           --------- OPTIMIZATION PARAMETERS ---------
         # these are used internally by the optimization algorithm and usually
@@ -318,12 +366,17 @@ class Parameters(BaseParameters):
         self.acquisition_raw_enabled = Parameter(start=False)
         self.acquisition_raw_decimation = Parameter(start=1)
         self.acquisition_raw_data = Parameter()
+        # raw acquisition has an additiona iir filter that can be used as low
+        # pass for preventing alias effects
+        self.acquisition_raw_filter_enabled = Parameter(start=False)
+        # The filter frequency in units of Hz
+        self.acquisition_raw_filter_frequency = Parameter(start=0)
         self.psd_data_partial = Parameter(start=None)
         self.psd_data_complete = Parameter(start=None)
+        self.psd_algorithm = Parameter(start=PSD_ALGORITHM_LPSD)
         self.psd_acquisition_running = Parameter(start=False)
         self.psd_optimization_running = Parameter(start=False)
         self.psd_acquisition_max_decimation = Parameter(start=18, min_=1, max_=32)
-        self.psd_acquisition_decimation_step = Parameter(start=1, min_=1, max_=4)
 
         #           --------- PARAMETERS OF GUI ---------
         self.plot_line_width = Parameter(start=2, min_=0.1, max_=100)
