@@ -1,23 +1,65 @@
 import pickle
 import random
 import string
+from time import sleep, time
+
 import numpy as np
-from time import time
+from pylpsd import lpsd
 from scipy import signal
 
+from linien.common import PSD_ALGORITHM_LPSD, PSD_ALGORITHM_WELCH
 from linien.server.optimization.engine import MultiDimensionalOptimizationEngine
 
 ALL_DECIMATIONS = list(range(32))
 
 
-def residual_freq_noise(dt, sig):
-    fs = 1 / dt
-    # num_pts = int(len(sig) / 128)
+def calculate_psd(sig, fs, algorithm):
+    """
+    Calculates the power spectral density.
+
+    :param sig: The signal to calculate the PSD for.
+    :param fs: The sampling frequency.
+    :param algorithm: The PSD algorithm to use. Options are 'lpsd' and 'welch'.
+    :return: One-sided power spectral density.
+    """
+    assert algorithm in [PSD_ALGORITHM_LPSD, PSD_ALGORITHM_WELCH]
+
+    # at beginning or end of signal, we sometimes have more glitches --> ignore
+    # them (200 points less @ 16384 points doesn't hurt much)
+    sig = sig[100:-100]
+
     num_pts = 256
-    hann = signal.hann(num_pts)
+    window = "hann"  # passed to scipy.signal.get_window for welch and lpsd
 
-    f, psd = signal.welch(sig, fs=fs, window=hann, nperseg=num_pts, scaling="density")
+    sig = sig.astype(np.float64)
 
+    if algorithm == PSD_ALGORITHM_WELCH:
+
+        f, Pxx = signal.welch(
+            sig, fs, window=window, nperseg=num_pts, scaling="density"
+        )
+    elif algorithm == PSD_ALGORITHM_LPSD:
+
+        fmin = fs / len(sig) * 10  # lowest frequency of interest
+        fmax = fs / 20.0  # highest frequency of interest
+
+        f, Pxx = lpsd(
+            sig,
+            fs,
+            window=window,
+            fmin=fmin,
+            fmax=fmax,
+            Jdes=256,
+            Kmin=2,
+            scaling="density",
+        )
+    return f, Pxx
+
+
+def residual_freq_noise(dt, sig, algorithm):
+    fs = 1 / dt
+
+    f, psd = calculate_psd(sig, fs, algorithm)
     # we want to have it in counts / Sqrt[Hz], not in (counts**2) / Hz
     psd = np.sqrt(psd)
 
@@ -75,11 +117,12 @@ class PSDAcquisition:
         if not self.is_child:
             self.control.pause_acquisition()
             self.parameters.acquisition_raw_enabled.value = False
-            self.control.exposed_write_data()
+            self.parameters.acquisition_raw_filter_enabled.value = False
+
+            self.control.exposed_write_registers()
             self.control.continue_acquisition()
 
     def react_to_new_signal(self, data_pickled):
-        # FIXME: erster Datenpunkt oder letzter haben manchmal glitches --> entfernen?
         try:
             if not self.running or self.parameters.pause_acquisition.value:
                 return
@@ -91,15 +134,14 @@ class PSDAcquisition:
             print("recording took", time() - self.time_decimation_set, "s")
             self.recorded_signals_by_decimation[current_decimation] = data
             self.recorded_psds_by_decimation[current_decimation] = residual_freq_noise(
-                1 / (125e6) * (2 ** (current_decimation)), data[0]
+                1 / (125e6) * (2 ** (current_decimation)),
+                data[0],
+                algorithm=self.parameters.psd_algorithm.value,
             )
 
-            # note: we don't precalculate the decimation values because we
-            # want the user to be able to change these values while the acquisition
-            # is running (i.e. if the user notices that it takes too long)
-            self.decimation_index += (
-                self.parameters.psd_acquisition_decimation_step.value
-            )
+            # this means that measurement time increases by a factor of 16 after
+            # each measurement
+            self.decimation_index += 4
 
             complete = (
                 self.decimation_index
@@ -146,7 +188,16 @@ class PSDAcquisition:
         self.control.pause_acquisition()
         self.parameters.acquisition_raw_decimation.value = decimation
         self.parameters.acquisition_raw_enabled.value = True
-        self.control.exposed_write_data()
+
+        # lowpass filter for preventing alias effects
+        self.parameters.acquisition_raw_filter_enabled.value = True
+        self.parameters.acquisition_raw_filter_frequency.value = int(
+            125e6 / (2 ** decimation) / 2
+        )
+
+        self.control.exposed_write_registers()
+        # take care that new decimation was actually written to FPGA
+        sleep(0.1)
         self.control.continue_acquisition()
 
     def exposed_stop(self):
