@@ -1,15 +1,16 @@
 import numpy as np
-
-from csr import PitayaCSR, make_filter
+from csr import PitayaCSR
+from iir_coeffs import make_filter
 from utils import twos_complement
-from linien.config import DEFAULT_RAMP_SPEED
+
 from linien.common import (
-    convert_channel_mixing_value,
-    LOW_PASS_FILTER,
-    HIGH_PASS_FILTER,
     ANALOG_OUT0,
+    HIGH_PASS_FILTER,
+    LOW_PASS_FILTER,
     MHz,
+    convert_channel_mixing_value,
 )
+from linien.config import DEFAULT_SWEEP_SPEED
 from linien.server.acquisition import AcquisitionMaster
 
 
@@ -43,11 +44,19 @@ class Registers:
 
         self.parameters.lock.on_change(lock_status_changed)
 
-        def fetch_quadratures_changed(v):
+        def fetch_additional_signals_changed(v):
             if self.acquisition is not None:
-                self.acquisition.fetch_quadratures_changed(v)
+                self.acquisition.fetch_additional_signals_changed(v)
 
-        self.parameters.fetch_quadratures.on_change(fetch_quadratures_changed)
+        self.parameters.fetch_additional_signals.on_change(
+            fetch_additional_signals_changed
+        )
+
+        def dual_channel_changed(dual_channel):
+            if self.acquisition is not None:
+                self.acquisition.set_dual_channel(dual_channel)
+
+        self.parameters.dual_channel.on_change(dual_channel_changed)
 
         use_ssh = self.host is not None and self.host not in ("localhost", "127.0.0.1")
         self.acquisition = AcquisitionMaster(use_ssh, self.host)
@@ -80,23 +89,26 @@ class Registers:
             # of stopping the sweep run after `request_lock` is set by setting
             # `sweep.clear`
             logic_sweep_run=1,
+            logic_sweep_pause=int(params["sweep_pause"]),
             logic_sweep_step=int(
-                DEFAULT_RAMP_SPEED
-                * params["ramp_amplitude"]
-                / (2 ** params["ramp_speed"])
+                DEFAULT_SWEEP_SPEED
+                * params["sweep_amplitude"]
+                / (2 ** params["sweep_speed"])
             ),
-            logic_sweep_min=-1 * _max(params["ramp_amplitude"] * 8191),
-            logic_sweep_max=_max(params["ramp_amplitude"] * 8191),
+            # NOTE: Sweep center is set by `logic_out_offset`.
+            logic_sweep_min=-1 * _max(params["sweep_amplitude"] * 8191),
+            logic_sweep_max=_max(params["sweep_amplitude"] * 8191),
             logic_mod_freq=params["modulation_frequency"],
             logic_mod_amp=params["modulation_amplitude"]
             if params["modulation_frequency"] > 0
             else 0,
             logic_dual_channel=int(params["dual_channel"]),
+            logic_fast_mode=int(params["fast_mode"]),
             logic_chain_a_factor=factor_a,
             logic_chain_b_factor=factor_b,
             logic_chain_a_offset=twos_complement(int(params["offset_a"]), 14),
             logic_chain_b_offset=twos_complement(int(params["offset_b"]), 14),
-            logic_out_offset=int(params["center"] * 8191),
+            logic_out_offset=int(params["sweep_center"] * 8191),
             logic_combined_offset=twos_complement(params["combined_offset"], 14),
             logic_control_channel=params["control_channel"],
             logic_mod_channel=params["mod_channel"],
@@ -111,20 +123,24 @@ class Registers:
             logic_autolock_robust_time_scale=params["autolock_time_scale"],
             logic_autolock_robust_final_wait_time=params["autolock_final_wait_time"],
             # channel A
-            fast_a_demod_delay=phase_to_delay(params["demodulation_phase_a"]),
+            fast_a_demod_delay=phase_to_delay(params["demodulation_phase_a"])
+            if params["modulation_frequency"] > 0
+            else 0,
             fast_a_demod_multiplier=params["demodulation_multiplier_a"],
             fast_a_dx_sel=self.csr.signal("zero"),
             fast_a_y_tap=2,
             fast_a_dy_sel=self.csr.signal("zero"),
             fast_a_invert=int(params["invert_a"]),
             # channel B
-            fast_b_demod_delay=phase_to_delay(params["demodulation_phase_b"]),
+            fast_b_demod_delay=phase_to_delay(params["demodulation_phase_b"])
+            if params["modulation_frequency"] > 0
+            else 0,
             fast_b_demod_multiplier=params["demodulation_multiplier_b"],
             fast_b_dx_sel=self.csr.signal("zero"),
             fast_b_y_tap=1,
             fast_b_dy_sel=self.csr.signal("zero"),
             fast_b_invert=int(params["invert_b"]),
-            # trigger on ramp
+            # trigger on sweep
             scopegen_external_trigger=1,
             gpio_p_oes=0b11111111,
             gpio_n_oes=0b11111111,
@@ -147,20 +163,27 @@ class Registers:
                 {
                     "scopegen_adc_a_sel": self.csr.signal(
                         "logic_combined_error_signal"
+                        if not params["acquisition_raw_filter_enabled"]
+                        else "logic_combined_error_signal_filtered"
                     ),
-                    "scopegen_adc_a_q_sel": self.csr.signal("zero"),
+                    "scopegen_adc_a_q_sel": self.csr.signal("fast_b_x"),
                     "scopegen_adc_b_sel": self.csr.signal("logic_control_signal"),
                     "scopegen_adc_b_q_sel": self.csr.signal("zero"),
                 }
             )
         else:
-            # display both demodulated error signals
+            # display both demodulated error signals (if dual channel mode)
+            # OR: display demodulated error signal 1 + monitor signal
             new.update(
                 {
                     "scopegen_adc_a_sel": self.csr.signal("fast_a_out_i"),
                     "scopegen_adc_a_q_sel": self.csr.signal("fast_a_out_q"),
-                    "scopegen_adc_b_sel": self.csr.signal("fast_b_out_i"),
-                    "scopegen_adc_b_q_sel": self.csr.signal("fast_b_out_q"),
+                    "scopegen_adc_b_sel": self.csr.signal(
+                        "fast_b_out_i" if params["dual_channel"] else "fast_b_x"
+                    ),
+                    "scopegen_adc_b_q_sel": self.csr.signal(
+                        "fast_b_out_q" if params["dual_channel"] else "zero"
+                    ),
                 }
             )
 
@@ -175,11 +198,11 @@ class Registers:
         )
         self.control._cached_data.update(new)
 
-        # pass ramp speed changes to acquisition process
-        sweep_changed = params["ramp_speed"] != self._last_sweep_speed
+        # pass sweep speed changes to acquisition process
+        sweep_changed = params["sweep_speed"] != self._last_sweep_speed
         if sweep_changed:
-            self._last_sweep_speed = params["ramp_speed"]
-            self.acquisition.set_ramp_speed(params["ramp_speed"])
+            self._last_sweep_speed = params["sweep_speed"]
+            self.acquisition.set_sweep_speed(params["sweep_speed"])
 
         raw_acquisition_settings = (
             params["acquisition_raw_enabled"],
@@ -189,6 +212,15 @@ class Registers:
             self._last_raw_acquisition_settings = raw_acquisition_settings
             self.acquisition.set_raw_acquisition(*raw_acquisition_settings)
 
+        fpga_base_freq = 125e6
+
+        self.set_iir(
+            "logic_raw_acquisition_iir",
+            *make_filter(
+                "LP", f=params["acquisition_raw_filter_frequency"] / fpga_base_freq, k=1
+            )
+        )
+
         for k, v in new.items():
             self.set(k, int(v))
 
@@ -263,20 +295,22 @@ class Registers:
                             "filter_%d_frequency_%s" % (iir_idx + 1, chain)
                         ]
 
-                    base_freq = 125e6
-
                     if not filter_enabled:
                         self.set_iir(iir_name, *make_filter("P", k=1))
                     else:
                         if filter_type == LOW_PASS_FILTER:
                             self.set_iir(
                                 iir_name,
-                                *make_filter("LP", f=filter_frequency / base_freq, k=1)
+                                *make_filter(
+                                    "LP", f=filter_frequency / fpga_base_freq, k=1
+                                )
                             )
                         elif filter_type == HIGH_PASS_FILTER:
                             self.set_iir(
                                 iir_name,
-                                *make_filter("HP", f=filter_frequency / base_freq, k=1)
+                                *make_filter(
+                                    "HP", f=filter_frequency / fpga_base_freq, k=1
+                                )
                             )
                         else:
                             raise Exception(
